==> qmmp_0.5.4.orig.tar.gz: qmmp-0.5.4/src/plugins/Input/cue/translations/cue_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Модуль CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Файлы CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>About CUE Audio Plugin</source>
        <translation>Об аудио-модуле CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="96"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Аудио-модуль CUE для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="97"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Настройки модуля CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Automatic file detection</source>
        <translation>Автоматический поиск файла</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Кодировка CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Определять кодировку автоматически</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Кодировка по умолчанию:</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Input/cue/translations/cue_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Модуль CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Файлы CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>About CUE Audio Plugin</source>
        <translation>Об аудио-модуле CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="96"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Аудио-модуль CUE для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="97"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Настройки модуля CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Загружать cue с ошибками, если возможно</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Кодировка CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Определять кодировку автоматически</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Кодировка по умолчанию:</translation>
    </message>
</context>
</TS>
